#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "util.h"

#define F(c,h,s) (c),(h),(s),((c)*(h)*(s))

static const struct diskfmt formats[] =
  {
    { "fd2",	    F( 40,1, 8), 0,  6,  8 },
    { "dd80",	    F( 40,1, 8), 0,  6,  8 },
    { "fd2d",	    F( 40,1,16), 0,  6,  8 },
    { "dd82",	    F( 40,1,16), 0,  6,  8 },
    { "abc830",     F( 40,1,16), 0,  6,  8 },
    { "abc830-ufd", F( 40,1,16), 0, 14, 16 },
    { "abc832",     F( 80,2,16), 2, 14, 16 },
    { "abc832",     F( 80,2,16), 2, 14, 16 },
    { "abc834",     F( 80,2,16), 2, 14, 16 },
    { "abc838",     F( 77,2,26), 2, 14, 16 },
    { "hd",         F(238,8,32), 5, 14, 16 },
    { NULL, F(0,0,0), 0, 0, 0 }
  };

const struct diskfmt *get_format(const char *name)
{
  const struct diskfmt *fmt;

  for (fmt = formats; fmt->name; fmt++) {
    if (!strcmp(fmt->name, name))
      return fmt;
  }

  return NULL;
}

void show_formats(FILE *f)
{
  const struct diskfmt *fmt;

  fprintf(f, "Format        Tracks  Sides  Sec/trk  Cluster  Sectors  Total  System\n");

  for (fmt = formats; fmt->name; fmt++) {
    fprintf(f, "%-13s %4d %6d %7d %9d %9d %6dK %5d\n",
	    fmt->name, fmt->c, fmt->h, fmt->s,
	    1 << fmt->cluster_shift,
	    fmt->sectors, fmt->sectors >> 2, fmt->syssec);
  }
}

    
