#ifndef UTIL_H
#define UTIL_H

#include <stdlib.h>
#include <stdio.h>

struct diskfmt {
  const char *name;
  unsigned char c, h, s;
  int sectors;			/* Total sectors (max 1911 clusters) */
  unsigned int cluster_shift;	/* Size of a cluster, log2 */
  int syssec;			/* First system sector (bitmap) */
  int dirsecs;			/* Number of directory sectors */
};

struct disk;

struct directory {
  struct disk *disk;		/* This directory belongs to... */
  unsigned char *bitmap;	/* Directory entry "bitmap" area */
  unsigned char *dirsec;	/* Actual directory sector */
  unsigned int block;		/* UFD block pointer (0 for MFD) */
};

struct disk {
  const struct diskfmt *fmt;	/* Format descriptor */
  unsigned char *image;		/* Image of the disk */
  unsigned char *bitmap;	/* Pointer to the bitmap inside the disk */
  struct directory mfd;		/* MFD directory descriptor */
};

const struct diskfmt *get_format(const char *);
void show_formats(FILE *);
struct disk *allocate_disk(const struct diskfmt *fmt);

extern const char *program;
void *xmalloc(size_t);

static inline void mark_used(struct disk *disk, unsigned int cluster)
{
  disk->bitmap[cluster >> 3] |= (0x80 >> (cluster & 7));
}

static inline int is_used(struct disk *disk, unsigned int cluster)
{
  return !!(disk->bitmap[cluster >> 3] & (0x80 >> (cluster & 7)));
}


#endif /* UTIL_H */
